==> aroundme_0_3_3.zip: aroundme_0_3_3/www/aroundme_0_3_3/language/1/am_default/my_library_edit.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2004 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'common_my.lang.php');
/*
* All language vars should be ordered TYPE, A-Z for convenience
* Tom Calthrop - 20th April 2004 (tom@barnraiser.org)
*/


//HEADER
$lang['hdr_document'] = 						"document";
$lang['hdr_library'] = 							"library";
$lang['hdr_page_names'] = 						"document names";


//BODY TEXT
$lang['txt_date'] = 							"date";
$lang['txt_default'] =							"default";
$lang['txt_default_help'] =						"Each Scrapbook has a default document. When someone visits your library, the default document is the first document that someone sees.";
$lang['txt_default_set'] =						"this is set as you default document. If you want to change it, edit the document that you want to be your default document";
$lang['txt_pagename'] = 						"page name";
$lang['txt_library_body'] = 					"Library item content.";
$lang['txt_library_body_help'] = 				"You must observe the group rules when publishing or editing a library item.";
$lang['txt_library_desc'] = 					"Library item description.";
$lang['txt_library_desc_help'] = 				"Give a short summary of the document. This is used on lists and summary pages.";
$lang['txt_library_title'] = 					"library title";
$lang['txt_library_title_help'] = 				"Use a decrcriptive name for your library entry.";
$lang['txt_wiki_default'] = 					"MyFirstPage"; //must be WIKI formatted LikeThisExample
$lang['txt_language'] = 						"language";
$lang['txt_language_help'] = 					"Language of this item.";

?>

==> aroundme-0_4_0.zip: aroundme_0_4_0/www/aroundme_0_4_0/language/1/am_default/my_library_edit.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'my_common.lang.php');
/*
* All language vars should be ordered TYPE, A-Z for convenience
* Tom Calthrop - 20th April 2004 (tom@barnraiser.org)
*/


//HEADER
$lang['hdr_document'] = 						"document";
$lang['hdr_library'] = 							"library";
$lang['hdr_page_names'] = 						"document names";
$lang['hdr_images'] = 							"images";


//BODY TEXT
$lang['txt_publish_node'] =						"everyone";
$lang['txt_publish_node_help'] =				"will appear in Splash and can be viewed by anyone.";
$lang['txt_publish_help'] =						"How wide do you want the audience of your blog to be? You can publish to just your friends, wider degrees of aquantances or the Splash magazine page.";
$lang['txt_date'] = 							"date";
$lang['txt_default'] =							"default";
$lang['txt_default_help'] =						"Each Scrapbook has a default document. When someone visits your library, the default document is the first document that someone sees.";
$lang['txt_default_set'] =						"this is set as you default document. If you want to change it, edit the document that you want to be your default document";
$lang['txt_pagename'] = 						"page name";
$lang['txt_library_body'] = 					"Library item content.";
$lang['txt_library_body_help'] = 				"You must observe the group rules when publishing or editing a library item.";
$lang['txt_library_desc'] = 					"Library item description.";
$lang['txt_library_desc_help'] = 				"Give a short summary of the document. This is used on lists and summary pages.";
$lang['txt_library_title'] = 					"library title";
$lang['txt_library_title_help'] = 				"Use a decrcriptive name for your library entry.";
$lang['txt_language'] = 						"language";
$lang['txt_language_help'] = 					"Language of this item.";
$lang['txt_allow_comments'] =					"check to allow comments against this item";
$lang['txt_images_help'] = 						"These are the images available to the group. Select one if you want it to appear next to this item.";

?>
